

from nltk.corpus.reader.util import *
from nltk.corpus.reader.api import *
from nltk.tokenize import *
from nltk_contrib.dependency import DepGraph

class DependencyCorpusReader(CorpusReader):
		
	def __init__(self, root, files,
        	     sep='/', word_tokenizer=TabTokenizer(),
                     sent_tokenizer=RegexpTokenizer('\n', gaps=True),
                     para_block_reader=read_blankline_block):
		
		CorpusReader.__init__(self, root, files)
        	
	#########################################################
		

	def raw(self, files=None):
        	"""
        	@return: the given file or files as a single string.
        	@rtype: C{str}self , lineNumber , files=None):
		sents=concat([DependencyCorpusView(filename, False, True, True)
                       	       for filename in self.abspaths(files)])
		dg=DepGraph().read(sents[lineNumber])
		return dg.deptree()
        	"""
        	return concat([open(filename).read()
                	       for filename in self.abspaths(files)])
	
	def words(self, files=None):
		return concat([DependencyCorpusView(filename, False, False, False)
		               for filename in self.abspaths(files)])
	
	def tagged_words(self, files=None):
		return concat([DependencyCorpusView(filename, True, False, False)
		               for filename in self.abspaths(files)])

	def sents(self, files=None):
		return concat([DependencyCorpusView(filename, False, True, False)
		               for filename in self.abspaths(files)])

	def tagged_sents(self, files=None):
        	return concat([DependencyCorpusView(filename, True, True, False)
                       	       for filename in self.abspaths(files)])

	def dependency_sents(self, files=None):
		return concat([DependencyCorpusView(filename, False, True, True)
                       	       for filename in self.abspaths(files)])
	
	def dependency_sent_tree(self , lineNumber , files=None):
		sents=concat([DependencyCorpusView(filename, False, True, True)
                       	       for filename in self.abspaths(files)])
		dg=DepGraph().read(sents[lineNumber])
		return dg.deptree()

	def dependency_sent_showTree(self , lineNumber , files=None):
		tree=self.dependency_sent_tree(lineNumber,files)
		tree.draw()
		

class DependencyCorpusView(StreamBackedCorpusView):
	 def __init__(self, corpus_file, tagged, group_by_sent, dependencies, 
                 chunk_types=None):
		self._tagged = tagged
		self._dependencies = dependencies
		self._group_by_sent = group_by_sent
		self._chunk_types = chunk_types
		StreamBackedCorpusView.__init__(self, corpus_file)
	 _DOCSTART = '-DOCSTART- -DOCSTART- O\n' #dokumentu hasiera definitzen da
	 def read_block(self, stream):
		# Read the next sentence.
		sent = read_blankline_block(stream)[0].strip()
		# Strip off the docstart marker, if present.
		if sent.startswith(self._DOCSTART):
		    sent = sent[len(self._DOCSTART):].lstrip()
		if not self._dependencies:	#If it is necessary to show the dependences the line does not need any change
			lines = [line.split('\t') for line in sent.split('\n')] #divide the line in 4 parts [word,category,dep_number,dep_type]
			if self._tagged:
		        	sent = [(word, tag) for (word, tag, dep_num, dep_type) in lines]
		    	else:
		        	sent = [word for (word, tag, dep_num, dep_type) in lines]
		# Return the result.
		if self._group_by_sent:
		    return [sent]
		else:
		    return list(sent)


