
# Natural Language Toolkit: Tagged Corpus Reader
#
# Copyright (C) 2001-2008 University of Pennsylvania
# Author: Edward Loper <edloper@gradient.cis.upenn.edu>
#         Steven Bird <sb@ldc.upenn.edu>
# URL: <http://nltk.sf.net>
# For license information, see LICENSE.TXT




from nltk.corpus.reader.util import *
from nltk.corpus.reader.api import *
from nltk.tokenize import *
from nltk_contrib.dependency import DepGraph

class MultiinfoCorpusReader(CorpusReader):
		
	def __init__(self, root, files,
        	     sep='/', word_tokenizer=TabTokenizer(),
                     sent_tokenizer=RegexpTokenizer('\n', gaps=True),
                     para_block_reader=read_blankline_block):
		
		CorpusReader.__init__(self, root, files)
        	
	#########################################################
		

	def raw(self, files=None):
        	"""
        	@return: the given file or files as a single string.
        	@rtype: C{str}self , lineNumber , files=None):
		sents=concat([DependencyCorpusView(filename, False, True, True)
                       	       for filename in self.abspaths(files)])
		dg=DepGraph().read(sents[lineNumber])
		return dg.deptree()
        	"""
        	return concat([open(filename).read()
                	       for filename in self.abspaths(files)])
	
	def words(self, files=None):
		return concat([MultiinfoCorpusView(filename, False, False, False, False)
		               for filename in self.abspaths(files)])
	
	def tagged_words(self, files=None):
		return concat([MultiinfoCorpusView(filename, True, False, False, False)
		               for filename in self.abspaths(files)])

	def sents(self, files=None):
		return concat([MultiinfoCorpusView(filename, False, True, False, False)
		               for filename in self.abspaths(files)])

	def tagged_sents(self, files=None):
        	return concat([MultiinfoCorpusView(filename, True, True, False, False)
                       	       for filename in self.abspaths(files)])

	def dependency_sents(self, files=None):
		return concat([MultiinfoCorpusView(filename, False, True, True, False)
                       	       for filename in self.abspaths(files)])
		
	def dependency_sent_tree(self , lineNumber , files=None):
		sents=concat([MultiinfoCorpusView(filename, False, True, True, False)
                       	       for filename in self.abspaths(files)])
		dg=DepGraph().read(sents[lineNumber])
		return dg.deptree()

	def dependency_sent_showTree(self , lineNumber , files=None):
		tree=self.dependency_sent_tree(lineNumber,files)
		tree.draw()

	def stemmed_words(self, files=None):
		return concat([MultiinfoCorpusView(filename, False, False, False, True)
		               for filename in self.abspaths(files)])	
	def stemmed_sents(self, files=None):
		return concat([MultiinfoCorpusView(filename, False, True, False, True)
		               for filename in self.abspaths(files)])	

class MultiinfoCorpusView(StreamBackedCorpusView):
	 def __init__(self, corpus_file, tagged, group_by_sent, dependencies, stems, 
                 chunk_types=None):
		self._tagged = tagged
		self._dependencies = dependencies
		self._stems = stems
		self._group_by_sent = group_by_sent
		self._chunk_types = chunk_types
		StreamBackedCorpusView.__init__(self, corpus_file)
	 _DOCSTART = '-DOCSTART- -DOCSTART- O\n' 
	 def read_block(self, stream):
		# Read the next sentence.
		sent = read_blankline_block(stream)[0].strip()
		# Strip off the docstart marker, if present.
		if sent.startswith(self._DOCSTART):
		    sent = sent[len(self._DOCSTART):].lstrip()

		lines = [line.split('\t') for line in sent.split('\n')]
		if self._dependencies:	#to show dependecies:
			 
			#split the line in 10 parts:
			#[line,hitza,stem,tag,subtag,info,dep_num,dep_type,x,y]
		    	sent = [ word + "\t" + subtag+ "\t" + dep_num+ "\t" + dep_type for (linenum, word, stem, tag, subtag, info, dep_num, dep_type,x,y) in lines]
			sent='\n'.join(sent) #a\tb\tc\td
		elif self._tagged:	#to show tags:
		        sent = [(word, subtag) for (linenum, word, stem, tag, subtag, info, dep_num, dep_type,x,y) in lines]
				    
		
		elif self._stems:	#to show stems:
		        sent = [(word,stem) for (linenum, word, stem, tag, subtag, info, dep_num, dep_type,x,y) in lines]

		else:
			sent = [word for (linenum, word, stem, tag, subtag, info, dep_num, dep_type,x,y) in lines]
		
		# Return the result.
		
		if self._group_by_sent:
		    	return [sent]
		else:
		    	return list(sent)


